<?php
/**
 * This script illustrates an example of request to the KMP to search for articles with category select
 *
 * @copyright web-site-scripts.com, 2010
 */
// including config
include 'config.php';
show_header("XML-RCP API :: Search Articles");

// setup method parameters
$method = new xmlrpcmsg(
    'get.Category.list', // method name
    array (          // parameters
        php_xmlrpc_encode(CLIENT_TOKEN),  // RPC-Client token to get access to resticted KMP features
        php_xmlrpc_encode(0),             // category id is 0 - select all categories and subcategories
        php_xmlrpc_encode('N'),           // public only is N - get all categories
        php_xmlrpc_encode('Y'),           // include subcategories is Y - include subcategories
    )
);

// setup client object
$client = new xmlrpc_client(URL_TO_KMP_RPC_SERVER);
$client->setDebug(0); // disable debugging

// send request to KMP XML-RPC API server
$result = $client->send($method);

if (! $result->faultCode()) { // continue if there have been no errors
    // get response formatted as PHP Array
    $list_categories = php_xmlrpc_decode($result->value());
} else { // show exception if error occured
    $error_message = "An error occurred: ";
    $error_message .= "Code: " . htmlspecialchars($result->faultCode()) . " Error: " . htmlspecialchars($result->faultString());
    show_error($error_message);
}

show_search_form($list_categories);

if ($_GET['searchText']) {
    if (isset($_GET['page']) && intval($_GET['page']) > 0) {
        $page_num = intval($_GET['page']);
    } else {
        $page_num = 1;
    }
    // setup method parameters
    $method = new xmlrpcmsg(
        'search.Articles', // method name
        array (          // parameters
            php_xmlrpc_encode(CLIENT_TOKEN),  // RPC-Client token to get access to resticted KMP features
            php_xmlrpc_encode($_GET['searchText'], array('base64')),        //search phrase - search for this text
            php_xmlrpc_encode('Y'),           //public only is Y - select only from public articles
            php_xmlrpc_encode(($page_num - 1) * REC_PER_PAGE),             //start id 0 - start from record 0
            php_xmlrpc_encode(REC_PER_PAGE),            //limit is 10 - select 10 records
            php_xmlrpc_encode('all'),         //search in is 'all' - search in all, can be 'articles', 'comments', 'attachments',
            php_xmlrpc_encode(intval($_GET['category_id'])),             //category id is 0 - search in all categories
            php_xmlrpc_encode('Y'),           //search in subcategories is Y - search in subcategories
            php_xmlrpc_encode(0),             //author id is 0 - search for any author
            php_xmlrpc_encode(array(
                'dateFilter' => 'custom',
                'dateFilterFrom' => '2001-01-01 01:01:01',
                'dateFilterTo' => '2021-01-01 01:01:01'
                )),    //date is 'all time' - can be 'today', 'yesterday', '7_days', '30_days', 'this_month', 'last_month', 'all_time', 'custom'
            php_xmlrpc_encode(array(
                                /*
                                array('cf_id' => '1',
                                      'value' => 'search'),
                                array('cf_id' => '2',
                                      'value' => 'search')
                                */
                                )),
                                /* custom fields is an array that contains of elemets like
                                array('cf_id' => '1',
                                      'value' => 'search')
                                cf_id is custom field id
                                value is the values that will besearched in custom field

                                */
            php_xmlrpc_encode('NLS'),         //search type is 'NLS' - natural language search
            php_xmlrpc_encode('all words'),   //search logic is 'all words' - search for all words
            php_xmlrpc_encode('N'),           //use query expansion is N - do no use query expansion
            php_xmlrpc_encode('Y'),           //highlight occurrences in Y - higlight search words in found articles
            php_xmlrpc_encode(255)            //preview length is 255 - length of text for preview
        )
    );

    // setup client object
    $client = new xmlrpc_client(URL_TO_KMP_RPC_SERVER);
    $client->setDebug(0); // disable debugging

    // send request to KMP XML-RPC API server
    $result = $client->send($method);

    // output page header
    //show_header("XML-RPC API :: Search Field Simple");

    if (! $result->faultCode()) { // continue if there have been no errors
        // get response formatted as PHP Array
        $response = php_xmlrpc_decode($result->value());

        // define title for articles list
        $header = "Search Field Simple";
        // get formatted articles list
        $data_articles = $response['articles'];
        $total_articles = $response['total'];
    } else { // show exception if error occured
        $error_message = "An error occurred: ";
        $error_message .= "Code: " . htmlspecialchars($result->faultCode()) . " Error: " . htmlspecialchars($result->faultString());
        show_error($error_message);
    }

    /*
     * Search categories
     */
    // setup method parameters
    $method = new xmlrpcmsg(
        'search.Categories', // method name
        array (          // parameters
            php_xmlrpc_encode(CLIENT_TOKEN),  // RPC-Client token to get access to resticted KMP features
            php_xmlrpc_encode($_GET['searchText'], array('base64')),        // search text - search categories for this text
            php_xmlrpc_encode('Y'),           // public only is Y - search only in public articles
            php_xmlrpc_encode(0),             // start is 0 - return starting from record 0
            php_xmlrpc_encode(REC_PER_PAGE),            // limit is 10 = return not more that 10 records
            php_xmlrpc_encode(intval($_GET['category_id'])),             // category id is 0 - search for all categories
            php_xmlrpc_encode('Y'),           // search in subcategories is Y - search in subcategories too
            php_xmlrpc_encode('NLS'),         // search type is nls - natural language search
            php_xmlrpc_encode('all words'),   // search logic is all words - search for all words
            php_xmlrpc_encode('N'),           // use query expansion is N - do not user query expansion
            php_xmlrpc_encode('Y')            // highlight occurrences is Y - highlight search words
        )
    );

    // setup client object
    $client = new xmlrpc_client(URL_TO_KMP_RPC_SERVER);
    $client->setDebug(0); // disable debugging

    // send request to KMP XML-RPC API server
    $result = $client->send($method);

    // output page header
    //show_header("XML-RPC API :: Search Field Simple");

    if (! $result->faultCode()) { // continue if there have been no errors
        // get response formatted as PHP Array
        $response = php_xmlrpc_decode($result->value());

        // get formatted list of categories
        $data_categories = $response['category'];
        $total_categories = $response['total'];
    } else { // show exception if error occured
        $error_message = "An error occurred: ";
        $error_message .= "Code: " . htmlspecialchars($result->faultCode()) . " Error: " . htmlspecialchars($result->faultString());
        show_error($error_message);
    }

    /*
     * get categories list to buld path for category search
     */
    // setup method parameters
    $method = new xmlrpcmsg(
        'get.Category.list', // method name
        array (          // parameters
            php_xmlrpc_encode(CLIENT_TOKEN),  // RPC-Client token to get access to resticted KMP features
            php_xmlrpc_encode(0),             // category id is 0 - select all categories and subcategories
            php_xmlrpc_encode('N'),           // public only is N - get all categories
            php_xmlrpc_encode('Y'),           // include subcategories is Y - include subcategories
        )
    );


    // setup client object
    $client = new xmlrpc_client(URL_TO_KMP_RPC_SERVER);
    $client->setDebug(0); // disable debugging

    // send request to KMP XML-RPC API server
    $result = $client->send($method);

    if (! $result->faultCode()) { // continue if there have been no errors
        // get response formatted as PHP Array
        $list_categories = php_xmlrpc_decode($result->value());

    } else { // show exception if error occured
        $error_message = "An error occurred: ";
        $error_message .= "Code: " . htmlspecialchars($result->faultCode()) . " Error: " . htmlspecialchars($result->faultString());
        show_error($error_message);
    }

    show_search_result($data_articles, $data_categories, $list_categories, $_GET['searchText'], $total_articles, $total_categories, $page_num);

    // output page footer
    show_footer();

}

?>