<?php
/**
 * This script is an example of XML-RPC API request to KMP.
 * It gets and shows a list of 10 recently added articles.
 *
 * @copyright Web-Site-Scripts.com, 2010
 */

// load configuration from config.php
include 'config.php';

// setup parameters for the request method
$method = new xmlrpcmsg(
    'get.Article.list.recentlyAdded', // method name
    array (          // parameters
        php_xmlrpc_encode(CLIENT_TOKEN),  // RPC-Client token to get access to resticted KMP features
        php_xmlrpc_encode(0),             // catgory id is 0 - select from all articles
        php_xmlrpc_encode(0),             // start shift is 0 - get list from the very begining
        php_xmlrpc_encode(10),            // limit of enties is 10 - we will get first ten account records
        php_xmlrpc_encode('Y')           // public only is Y - select only public articles
    )
);

// setup client object
$client = new xmlrpc_client(URL_TO_KMP_RPC_SERVER);
$client->setDebug(0); // disable debugging

// send request to KMP XML-RPC API server
$result = $client->send($method);

// output page header
show_header("XML-RPC API :: Get 10 Recently Added Articles");

if (! $result->faultCode()) { // continue if there have been no errors
    // get response formatted as PHP Array
    $response = php_xmlrpc_decode($result->value());

    // define title for articles list
    $header = "Recently Added Articles";
    // get formatted articles list
    $data = $response['articles'];

    show_ArticleList($header, $data);

} else { // show exception if error occured
    $error_message = "An error occurred: ";
    $error_message .= "Code: " . htmlspecialchars($result->faultCode()) . " Error: " . htmlspecialchars($result->faultString());
    show_error($error_message);
}

// output page footer
show_footer();
?>