<?php
/**
 * Copy 1kb 1 to kb 2 using api
 *
 * @copyright web-site-scripts.com, 2010
 */

require_once('common.php');
 
// RPC-Client Token
// Replace this token with your valid client token
if (!defined(CLIENT_TOKEN_SOURCE)) {
    define('CLIENT_TOKEN_SOURCE', '415241f8b289cd769988ef6c66');
}
// URL to your KMP RPC server. Normaly it's an URL to KMP frontend plus 'api.php'
// Do not forget to change this URL accordingly
if (!defined(URL_TO_KMP_RPC_SERVER_SOURCE)) {
    define('URL_TO_KMP_RPC_SERVER_SOURCE', 'http://demo.web-site-scripts.com/kmp/demo123/api.php');
}

// RPC-Client Token
// Replace this token with your valid client token
if (!defined(CLIENT_TOKEN_DEST)) {
    define('CLIENT_TOKEN_DEST', '535ded765f0d9f4fbf89ca706d1');
}
// URL to your KMP RPC server. Normaly it's an URL to KMP frontend plus 'api.php'
// Do not forget to change this URL accordingly
if (!defined(URL_TO_KMP_RPC_SERVER_DEST)) {
    define('URL_TO_KMP_RPC_SERVER_DEST', 'http://demo/anton-kmp-pack/api.php');
}

// include XML RPC library
include_once '../lib/xmlrpc.inc';

// STEP 1
// get categories tree from KB 1
// setup method parameters
$method = new xmlrpcmsg(
    'get.Category.tree', // method name
    array (          // parameters
        php_xmlrpc_encode(CLIENT_TOKEN_SOURCE),  // RPC-Client token to get access to resticted KMP features
        php_xmlrpc_encode(0),             // category id is 0 - select all categories and subcategories
        php_xmlrpc_encode('N'),           // public only is N - get all categories
    )
);

// setup client object
$client = new xmlrpc_client(URL_TO_KMP_RPC_SERVER_SOURCE);
$client->setDebug(0); // disable debugging

// sending request to KMP RPC server
$result = $client->send($method);

if (! $result->faultCode()) { // continue if there are no errors happened
    $cats = $result->value();

	// have result with tree
    $cat_tree = php_xmlrpc_decode($cats);

} else { // show the exception
    print "An error occurred: ";
    print "Code: " . htmlspecialchars($result->faultCode()) . " Error: " . htmlspecialchars($result->faultString());
}


// STEP 2
// create categories tree in new KB
$cat_tree = create_tree($cat_tree, 0);


// STEP 3
// build conversional array (to convert KB1 cat ids to KB2 cat ids in articles)
$conv_arr = build_conv_array($cat_tree);

// STEP 4
// copy all articles from categories from KB1 to categories in KB2
copy_articles($cat_tree, $conv_arr);

echo '<strong>Done</strong>';
exit;



// adds categories and their subcategories (recursive)
function create_tree($tree, $parent_id)
{
	if (!count($tree)) {
		return $tree;
	}
	foreach ($tree as $key => $el) {
		// add category
		if ($el['pid'] == null) {
			$el['pid'] = 0;
		}
		// setup method parameters
		$method = new xmlrpcmsg(
			'add.Category', // method name
			array (          // parameters
				php_xmlrpc_encode(CLIENT_TOKEN_DEST),  // RPC-Client token to get access to resticted KMP features
				php_xmlrpc_encode($el['text']),        // category name
				php_xmlrpc_encode($parent_id),             // parent category id
				php_xmlrpc_encode($el['meta_keywords']),// meta _keywords
				php_xmlrpc_encode($el['meta_description']),// meta description
				php_xmlrpc_encode($el['position']),        // position
				php_xmlrpc_encode($el['public']),// public
				php_xmlrpc_encode(array ()) // group_ids
			)
		);

		// setup client object
		$client = new xmlrpc_client(URL_TO_KMP_RPC_SERVER_DEST);
		$client->setDebug(0); // disable debugging

		// sending request to KMP RPC server
		$result = $client->send($method);

		if (! $result->faultCode()) { // continue if there are no errors happened
			$cat = $result->value();
			// show RPC server response on the page
			$result = php_xmlrpc_decode($cat);

		} else { // show the exception
			print "An error occurred: ";
			print "Code: " . htmlspecialchars($result->faultCode()) . " Error: " . htmlspecialchars($result->faultString());
		}

		// update category id (to add articles to it later in new KB)
		$tree[$key]['kb_source_id'] = $tree[$key]['id'];
		$tree[$key]['id'] = $result['catID'];
		$tree[$key]['kb_source_pid'] = $tree[$key]['pid'];
		$tree[$key]['pid'] = $parent_id;

		// check if category has childs
		if (count($el['child'])) {
			$tree[$key]['child'] = create_tree($el['child'], $tree[$key]['id']);
		}

	}
	return $tree;
}


// builds conversional tree (to convert KB1 cat ids to KB2 cat ids in articles) (recursive)
function build_conv_array($tree)
{
	if (!count($tree)) {
		return $tree;
	}
	$conv_arr = array();
	foreach ($tree as $el) {
		$conv_arr[$el['kb_source_id']] = $el['id'];
		if (count($el['child'])) {
			$conv_arr = array_merge_recursive_unique ($conv_arr, build_conv_array($el['child']));
		}
	}
	return $conv_arr;
}


// copoes articles to new KB (recursive)
function copy_articles($tree, $conv_arr)
{
	if (!count($tree)) {
		return $tree;
	}
	// get list of articles in KB 1
	unset($art_arr);
	// setup method parameters
	$method = new xmlrpcmsg(
		'get.Article.list', // method name
		array (          // parameters
			php_xmlrpc_encode(CLIENT_TOKEN_SOURCE),  // RPC-Client token to get access to resticted KMP features
			php_xmlrpc_encode(0),             // catgory id is 0 - select from all articles
			php_xmlrpc_encode(0),             // start shift is 0 - get list from the very begining
			php_xmlrpc_encode(1000),            // limit of enties is 10 - we will get first ten account records
			php_xmlrpc_encode('N'),           // public only is Y - select only public articles
			php_xmlrpc_encode('N'),           // featured only is N - select all articles
			php_xmlrpc_encode('faq_id'),       // sort by is views - sort by views column
			php_xmlrpc_encode('asc'),        // sort order is asc - select in ascending order
		)
	);

	// setup client object
	$client = new xmlrpc_client(URL_TO_KMP_RPC_SERVER_SOURCE);
	$client->setDebug(0); // disable debugging

	// sending request to KMP RPC server
	$result = $client->send($method);

	if (! $result->faultCode()) { // continue if there are no errors happened
		$articles = $result->value();

		$result = php_xmlrpc_decode($articles);

		$art_arr = $result['articles'];

	} else { // show the exception
		print "An error occurred: ";
		print "Code: " . htmlspecialchars($result->faultCode()) . " Error: " . htmlspecialchars($result->faultString());
	}

	// convert id's of article's categories to ids from KB2
	foreach ($art_arr as $art_key => $art_el) {
		foreach ($art_el['categories'] as $cat_key => $cat) {
			$art_arr[$art_key]['categories'][$cat_key]['catID'] = $conv_arr[$cat['catID']];
		}
	}	

	// add articles to kb2
	foreach ($art_arr as $art_key => $art_el) {
		// build array of categories that contain this article
		$cat_arr = array();
		foreach ($art_el['categories'] as $cat_key => $cat) {
			$cat_arr[] = $cat['catID'];
		}

		// setup method parameters
		$method = new xmlrpcmsg(
			'add.Article', // method name
			array (          // parameters
				php_xmlrpc_encode(CLIENT_TOKEN_DEST),  // RPC-Client token to get access to resticted KMP features
				php_xmlrpc_encode($art_el['question'], array('base64')),        // title
				php_xmlrpc_encode($art_el['answer'], array('base64')),             // content
				php_xmlrpc_encode($cat_arr),// array with catgory id's

			)
		);

		// setup client object
		$client = new xmlrpc_client(URL_TO_KMP_RPC_SERVER_DEST);
		$client->setDebug(0); // disable debugging

		// sending request to KMP RPC server
		$result = $client->send($method);

		if (! $result->faultCode()) { // continue if there are no errors happened
			$articles = $result->value();

			// show RPC server response on the page

			echo '<pre>';
			$result = php_xmlrpc_decode($articles);
			//print_r($result);
			//print_r(array_to_entities($result));
			echo '</pre><br />';

		} else { // show the exception
			print "An error occurred: ";
			print "Code: " . htmlspecialchars($result->faultCode()) . " Error: " . htmlspecialchars($result->faultString());
		}
	}
}


/**
 *
 * In this version the values are overwritten only if they are not an array.
 * If the value is an array, its elements will be merged/overwritten:
 * array_merge_recursive which override value with next value.
 * based on: http://www.php.net/manual/hu/function.array-merge-recursive.php
 *
 * @param unknown_type $array0
 * @param unknown_type $array1
 * @return unknown
 */
function array_merge_recursive_unique($array0, $array1) {
    $arrays = func_get_args();
    $remains = $arrays;

    // We walk through each arrays and put value in the results (without
    // considering previous value).
    $result = array();

    // loop available array
    foreach($arrays as $array) {

        // The first remaining array is $array. We are processing it. So
        // we remove it from remaing arrays.
        array_shift($remains);

        // We don't care non array param, like array_merge since PHP 5.0.
        if(is_array($array)) {
            // Loop values
            foreach($array as $key => $value) {
                if(is_array($value)) {
                    // we gather all remaining arrays that have such key available
                    $args = array();
                    foreach($remains as $remain) {
                        if(array_key_exists($key, (array)$remain)) {
                            array_push($args, $remain[$key]);
                        }
                    }

                    if(count($args) > 2) {
                        // put the recursion
                        $result[$key] = call_user_func_array(__FUNCTION__, $args);
                    } else {
                        foreach($value as $vkey => $vval) {
                            $result[$key][$vkey] = $vval;
                        }
                    }
                } else {
                    // simply put the value
                    $result[$key] = $value;
                }
            }
        }
    }
    return $result;
}

?>