<?php
/**
 * This script illustrates an example of request to the KMP to get a list ofarticles and save them to CSV file (export)
 *
 * @copyright web-site-scripts.com, 2010
 */

define('CSV_DELIMITER', ',');
define('CSV_FILE_NAME', 'export.csv');
define('CSV_TEMP_FILE', 'export_temp.csv');


require_once('common.php');

// RPC-Client Token
// Replace this token with your valid client token
if (!defined(CLIENT_TOKEN)) {
    define('CLIENT_TOKEN', '5ef9ae9ecb7b551ed235cc88f7b4455f');
}

// URL to your KMP RPC server. Normaly it's an URL to KMP frontend plus 'api.php'
// Do not forget to change this URL accordingly
if (!defined(URL_TO_KMP_RPC_SERVER)) {
    define('URL_TO_KMP_RPC_SERVER', 'http://example.host/kb/api.php');
}

// include XML RPC library
include_once '../lib/xmlrpc.inc';

// setup method parameters
$method = new xmlrpcmsg(
    'get.Article.list', // method name
    array (          // parameters
        php_xmlrpc_encode(CLIENT_TOKEN),  // RPC-Client token to get access to resticted KMP features
        php_xmlrpc_encode(0),             // catgory id is 0 - select from all articles
        php_xmlrpc_encode(0),             // start shift is 0 - get list from the very begining
        php_xmlrpc_encode(1000),            // limit of enties is 10 - we will get first ten account records
        php_xmlrpc_encode('N'),           // public only is Y - select only public articles
        php_xmlrpc_encode('N'),           // featured only is N - select all articles
        php_xmlrpc_encode('faq_id'),       // sort by is faq_id - sort by faq_id column
        php_xmlrpc_encode('asc'),        // sort order is asc - select in ascending order
    )
);

// setup client object
$client = new xmlrpc_client(URL_TO_KMP_RPC_SERVER);
$client->setDebug(0); // disable debugging

// sending request to KMP RPC server
$result = $client->send($method);

if (! $result->faultCode()) { // continue if there are no errors happened
    $articles = $result->value();

    //get responce from the server
    $result = php_xmlrpc_decode($articles);

    if (!$fp = fopen(CSV_TEMP_FILE, 'w')) {
    	print "An error occurred: ";
        print "Temporary file " . CSV_TEMP_FILE . " is not writable";
        exit;
    }
    fwrite($fp, 'Title,Body,Publish,Rating,Views,Created on,Categories' . "\r\n");	

	foreach($result['articles'] as $el) {
		$categories = '';
		foreach ($el['categories'] as $cat) {
			if (!empty($categories)) {
				$categories .= ', ';
			}
			$categories .= str_replace('"', '""', html_entity_decode($cat['catName'], ENT_COMPAT, 'UTF-8'));
		}

		$csv = '';
		$csv .= '"' . $el['question'] . '"';
		$csv .= CSV_DELIMITER;
		$csv .= '"' . str_replace('"','""', $el['answer']) . '"';
		$csv .= CSV_DELIMITER;
		$csv .= $el['public'] ? 'Yes' : 'No';
		$csv .= CSV_DELIMITER;
		$csv .= $el['rating']; //temporary
		$csv .= CSV_DELIMITER;
		$csv .= $el['views']; //temporary
		$csv .= CSV_DELIMITER;
		$csv .= date('m/d/Y', $el['date']);
		$csv .= CSV_DELIMITER;
		$csv .= '"' . $categories . '"';
		$csv .= "\r\n";

		fwrite($fp, $csv);
	}
	fclose($fp);


	header ('Cache-Control: must-revalidate, post-check=0, pre-check=0');
	header ('Content-Type: application/octet-stream');
	header ('Content-Length: ' . filesize(CSV_TEMP_FILE));
	header ('Content-Disposition: attachment; filename="' . CSV_FILE_NAME . '"');

	$fp = fopen(CSV_TEMP_FILE, 'r');
	while (!feof($fp)) {
	   $tmp = fread($fp, 1024); // read by 1 kByte
	   echo $tmp;
	}
	fclose($fp);
	exit;



} else { // show the exception
    print "An error occurred: ";
    print "Code: " . htmlspecialchars($result->faultCode()) . " Error: " . htmlspecialchars($result->faultString());
	exit;
}

?>